@@ -1,6 +1,8 @@
 from __future__ import annotations
 
-from pydantic import BaseModel, Field, field_validator
+from pydantic import Field, field_validator
+
+from ._base import BaseModel
 
 __all__ = ("Quest",)
 
